Enum Request
#[non_exhaustive]pub enum Request {
Destroy,
SetModal,
UnsetModal,
}wayland and Linux only.Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Destroy
destroy the dialog object
Destroys the xdg_dialog_v1 object. If this object is destroyed before the related xdg_toplevel, the compositor should unapply its effects.
This is a destructor, once received this object cannot be used any longer.
SetModal
mark dialog as modal
Hints that the dialog has “modal” behavior. Modal dialogs typically require to be fully addressed by the user (i.e. closed) before resuming interaction with the parent toplevel, and may require a distinct presentation.
Clients must implement the logic to filter events in the parent toplevel on their own.
Compositors may choose any policy in event delivery to the parent toplevel, from delivering all events unfiltered to using them for internal consumption.
UnsetModal
mark dialog as not modal
Drops the hint that this dialog has “modal” behavior. See xdg_dialog_v1.set_modal for more details.
Implementations